nx.graphic.Topology.Event - Next UI Toolkit

#

API Docs for: trial
Show: Inherited Protected Private Deprecated

# nx.graphic.Topology.Event Class

Module: nx.graphic.Topology

Topology base events

- Index
- Properties
- Events

## Item Index

### Properties

- enableGradualScaling

### Events

- clickStage
- down
- dragStage
- dragStageEnd
- dragStageStart
- enter
- esc
- left
- pressA
- pressF
- pressM
- pressR
- pressS
- pressStage
- right
- space
- up
- zoomend
- zooming

## Properties

### `enableGradualScaling`

Boolean

Enabling gradual scaling feature when zooming, set to false will improve the performance

## Events

### `clickStage`

Fired when click the stage

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `down`

Fired when press down arrow key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `dragStage`

Fired when dragging stage

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `dragStageEnd`

Fired when drag end stage

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `dragStageStart`

Fired when start drag stage

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `enter`

Fired when press enter key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `esc`

Fired when press esc key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `left`

Fired when press left arrow key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `pressA`

Fired when press a key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `pressF`

Fired when press f key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `pressM`

Fired when press m key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `pressR`

Fired when press r key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `pressS`

Fired when press s key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `pressStage`

Fired when mouse press stage, this is a capture event

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `right`

Fired when press right arrow key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `space`

Fired when press space key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `up`

Fired when press up arrow key

#### Event Payload:

- `sender` Object

  Trigger instance

- `event` Object

  original event object

### `zoomend`

Fired when end zooming

#### Event Payload:

- `sender` Object

  trigger instance

- `event` Object

  original event object

### `zooming`

Fired when zooming stage

#### Event Payload:

- `sender` Object

  trigger instance

- `scale` Number

  stage current scale